@@ -39,6 +39,7 @@ import requests
 
 from pyimgur import request
 
+__version__ = "0.5.1"
 
 AUTHORIZE_URL = ("https://api.imgur.com/oauth2/authorize?"
                  "client_id=%s&response_type=%s&state=%s")
@@ -55,7 +56,7 @@ def _change_object(from_object, to_object):
 def _get_album_or_image(json, imgur):
     """Return a gallery image/album depending on what the json represent."""
     if json['is_album']:
-        return Gallery_album(json, imgur)
+        return Gallery_album(json, imgur, has_fetched=False)
     return Gallery_image(json, imgur)
 
 
@@ -114,7 +115,7 @@ class Basic_object(object):
                 self.author = User({'url': self.account_url}, self._imgur,
                                    has_fetched=False)
                 del self.account_url
-            if "cover" in vars(self):
+            if "cover" in vars(self) and self.cover is not None:
                 self.cover = Image({'id': self.cover}, self._imgur,
                                    has_fetched=False)
             if "images" in vars(self):
@@ -230,7 +231,11 @@ class Album(Basic_object):
     :ivar deletehash: For anonymous uploads, this is used to delete the album.
     :ivar description: A short description of the album.
     :ivar id: The ID for the album.
-    :ivar images: A list of the images in this album.
+    :ivar images: A list of the images in this album. Only set at instantiation
+        if created with Imgur.get_album. But even if it isn't set, then you can
+        still access the attribute. This will make PyImgur fetch the newest
+        version of all attributes for this class, including images. So it will
+        work as though images was set all along.
     :ivar is_favorited: Has the logged in user favorited this album?
     :ivar is_nsfw: Is the album Not Safe For Work (contains gore/porn)?
     :ivar layout: The view layout of the album.
@@ -352,10 +357,13 @@ class Album(Basic_object):
             self.layout = layout or self.layout
             self.privacy = privacy or self.privacy
             if cover is not None:
-                self.cover = Image(cover)
+                self.cover = (cover if isinstance(cover, Image)
+                              else Image({'id': cover}, self._imgur,
+                                         has_fetched=False))
             if images:
                 self.images = [img if isinstance(img, Image) else
-                               Image(img, self._imgur) for img in images]
+                               Image({'id': img}, self._imgur, False)
+                               for img in images]
         return is_updated
 
 
@@ -751,7 +759,7 @@ class Imgur:
         :param description: The albums description.
         :param images: A list of the images that will be added to the album
             after it's created.  Can be Image objects, ids or a combination of
-            the two.  Images that you cannot add (non-existing or not owned by
+            the two. Images that you cannot add (non-existing or not owned by
             you) will not cause exceptions, but fail silently.
         :param cover: The id of the image you want as the albums cover image.
 
@@ -1074,7 +1082,7 @@ class Imgur:
         :param title: The title the image will have when uploaded.
         :param description: The description the image will have when uploaded.
         :param album: The album the image will be added to when uploaded. Can
-            be either a Album object or it's id.  Leave at None to upload
+            be either a Album object or it's id. Leave at None to upload
             without adding to an Album, adding it later is possible.
             Authentication as album owner is necessary to upload to an album
             with this function.
@@ -1247,7 +1255,7 @@ class User(Basic_object):
         url = "https://api.imgur.com/3/account/%s/albums/%s" % (self.name,
                                                                 '%d')
         resp = self._imgur._send_request(url, limit=limit)
-        return [Album(alb, self._imgur) for alb in resp]
+        return [Album(alb, self._imgur, False) for alb in resp]
 
     def get_comments(self):
         """Return the comments made by the user."""
